==> haskell-hasql-implicits-0.1.0.5-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-9Sa4EcpbzHPAC0Iz0JSKLn
key:                  hasql-implicits-0.1.0.5-9Sa4EcpbzHPAC0Iz0JSKLn
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  5ff512ca3cf3921f3563f81c4a7151eb
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-9Sa4EcpbzHPAC0Iz0JSKLn
depends:
    aeson-2.1.2.1-8ueLuG1qYj9Fbt4mgkSEM3 base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    hasql-1.5.0.4-36c9bCp7RVxC0FOvOq8naQ
    network-ip-0.3.0.3-KACnSFmExSDIzujAE3LUFV
    scientific-0.3.7.0-5LYId1uMyYd6WtLuciLYcq text-1.2.5.0
    time-1.11.1.1 uuid-1.3.15-DHFkgyemV7tAPyzN8xQ6lb
    vector-0.13.1.0-IsxGr1wjc8yHuZdiqe6rZF

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-implicits-0.1.0.5-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-3Orq7Mr2aAmKvwpYYPuKRS
key:                  hasql-implicits-0.1.0.5-3Orq7Mr2aAmKvwpYYPuKRS
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  bb75fa3ae2b387a2c28804809a7c1643
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-3Orq7Mr2aAmKvwpYYPuKRS
depends:
    aeson-2.1.2.1-3lugcDour1r4V4jv6ZKvkq base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    hasql-1.5.0.4-CsvXE1qi8fU3CqpDEbUWLi
    network-ip-0.3.0.3-GMsfRsT1o6jIOiGBchyBWQ
    scientific-0.3.7.0-7p41gUaaSP7BrDOTk8p39O text-1.2.5.0
    time-1.11.1.1 uuid-1.3.15-842xa3J9NwW72ekLFfbfwV
    vector-0.13.1.0-HRMJcTNtHmH9PMIsGjP73X

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
